==> aspose-words-cloud-20.4.0.tar.gz: aspose-words-cloud-20.4.0/test/__init__.py <==
from test.Common.test_error_handling import TestErrorHandling
from test.Common.test_font import TestFont
from test.Document.test_document import TestDocument
from test.DocumentActions.test_append_document import TestAppendDocument
from test.DocumentActions.test_classification import TestClassification
from test.DocumentActions.test_compare_document import TestCompareDocument
from test.DocumentActions.test_convert_document import TestConvertDocument
from test.DocumentActions.test_document_protection import TestDocumentProtection
from test.DocumentActions.test_document_statistics import TestDocumentStatistics
from test.DocumentActions.test_execute_mail_merge import TestExecuteMailMerge
from test.DocumentActions.test_load_web_document import TestLoadWebDocument
from test.DocumentActions.test_mail_merge_fields import TestMailMergeFields
from test.DocumentActions.test_revisions import TestRevisions
from test.DocumentActions.test_split_document import TestSplitDocument
from test.DocumentElements.test_bookmarks import TestBookmarks
from test.DocumentElements.test_comments import TestComments
from test.DocumentElements.test_document_properties import TestDocumentProperties
from test.DocumentElements.test_drawing_objects import TestDrawingObjects
from test.DocumentElements.test_fields import TestFields
from test.DocumentElements.test_footnote import TestFootnote
from test.DocumentElements.test_form_field import TestFormField
from test.DocumentElements.test_header_footer import TestHeaderFooter
from test.DocumentElements.test_hyperlinks import TestHyperlinks
from test.DocumentElements.test_macros import TestMacros
from test.DocumentElements.test_math_objects import TestMathObjects
from test.DocumentElements.test_pages import TestPages
from test.DocumentElements.test_paragraphs import TestParagraphs
from test.DocumentElements.test_runs import TestRuns
from test.DocumentElements.test_sections import TestSections
from test.DocumentElements.test_tables import TestTables
from test.DocumentElements.test_text import TestText
from test.DocumentElements.test_watermarks import TestWatermarks
from test.Storage.test_file import TestFile
from test.Storage.test_folder import TestFolder
from test.Range.test_range import TestRange

==> aspose-words-cloud-20.6.0.tar.gz: aspose-words-cloud-20.6.0/test/__init__.py <==
from test.Common.test_error_handling import TestErrorHandling
from test.Common.test_font import TestFont
from test.Document.test_document import TestDocument
from test.DocumentActions.test_append_document import TestAppendDocument
from test.DocumentActions.test_classification import TestClassification
from test.DocumentActions.test_compare_document import TestCompareDocument
from test.DocumentActions.test_convert_document import TestConvertDocument
from test.DocumentActions.test_reporting import TestReporting
from test.DocumentActions.test_document_protection import TestDocumentProtection
from test.DocumentActions.test_document_statistics import TestDocumentStatistics
from test.DocumentActions.test_execute_mail_merge import TestExecuteMailMerge
from test.DocumentActions.test_load_web_document import TestLoadWebDocument
from test.DocumentActions.test_mail_merge_fields import TestMailMergeFields
from test.DocumentActions.test_revisions import TestRevisions
from test.DocumentActions.test_split_document import TestSplitDocument
from test.DocumentElements.test_bookmarks import TestBookmarks
from test.DocumentElements.test_comments import TestComments
from test.DocumentElements.test_document_properties import TestDocumentProperties
from test.DocumentElements.test_drawing_objects import TestDrawingObjects
from test.DocumentElements.test_fields import TestFields
from test.DocumentElements.test_footnote import TestFootnote
from test.DocumentElements.test_form_field import TestFormField
from test.DocumentElements.test_header_footer import TestHeaderFooter
from test.DocumentElements.test_hyperlinks import TestHyperlinks
from test.DocumentElements.test_macros import TestMacros
from test.DocumentElements.test_math_objects import TestMathObjects
from test.DocumentElements.test_pages import TestPages
from test.DocumentElements.test_paragraphs import TestParagraphs
from test.DocumentElements.test_runs import TestRuns
from test.DocumentElements.test_sections import TestSections
from test.DocumentElements.test_tables import TestTables
from test.DocumentElements.test_text import TestText
from test.DocumentElements.test_watermarks import TestWatermarks
from test.DocumentElements.test_lists import TestLists
from test.Storage.test_file import TestFile
from test.Storage.test_folder import TestFolder
from test.Range.test_range import TestRange
from test.DocumentElements.test_styles import TestStyles
